@@ -3,7 +3,7 @@
 #'
 #' @description This function creates the required spatial outputs for the target node.
 #' @param target character. The node of interest to be modelled and mapped.
-#' @param statesProb matrix. The probability matrix as returned by \code{\link{queryNet}} and \code{queryNetParallel}.
+#' @param statesProb matrix. The probability matrix as returned by \code{\link{queryNet}} and \code{queryNetParallel}. Named columns required, accordingly to states.
 #' Columns are the \code{target} node states and rows each location considered from the area of interest.
 #' @param what character. The required output, one or more of these values are valid:
 #' \itemize{
@@ -52,14 +52,18 @@
 #' target <- 'FinalLULC'
 #' statesProb <- queryNet(network, target, evidence)
 #' 
-#' maps <- mapTarget(target, statesProb, msk=currentLU)
+#' maps <- mapTarget(target, statesProb, msk=ConwyLU)
 #' 
 #' library(raster)
 #' plot(maps$Class)
 #' plot(maps$Entropy)
 #' 
+#' ## Returns required outputs by coordinates for each 'msk' cell in a data frame:
+#' noMap <- mapTarget(target, statesProb, msk=ConwyLU, spatial=FALSE)
+#' head(noMap)
+#' 
 #' ## Create a probability surface for the "forest" state of target node "FinalLULC"
-#' mp <- mapTarget('FinalLULC', statesProb, what='probability', targetState='forest', msk=currentLU)
+#' mp <- mapTarget('FinalLULC', statesProb, what='probability', targetState='forest', msk=ConwyLU)
 #' plot(mp$Probability$forest)
 #' 
 #' @export
@@ -71,33 +75,35 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
         #match.arg(exportRaster, c('.asc','.sdat','.rst','.nc','.tif','.envi','.bil'))
         rFormat <- exportRaster
     }
-    what <- match.arg(what, c("class", "entropy", "probability", "expected", "variation"), several.ok = TRUE)
-    if(spatial == TRUE){ 
-        if(class(msk) == 'RasterLayer'){
-            id <- msk
-            id[] <- seq_along(id)
-            id <- raster::getValues(id)[!is.na(raster::getValues(msk))]
-            msk[] <- NA
-        } else { 
-            stop('Please provide a valid "msk" argument (an object of class "RasterLayer"), or set spatial=FALSE.')
-        }
+    what <- match.arg(what, c("class", "entropy", "probability", "expected", "variation"), several.ok=TRUE)
+    if(class(msk) != 'RasterLayer'){
+        stop('Please provide a valid "msk" argument (an object of class "RasterLayer").')
+    }
+    if(spatial == TRUE){
+        msk_cells_ID <- msk
+        msk_cells_ID[] <- seq_along(msk_cells_ID)
+        msk_cells_ID <- raster::getValues(msk_cells_ID)[!is.na(raster::getValues(msk))]
+        msk[] <- NA
+    } else {
+        msk_cells_ID <- seq_along(msk)
+        msk_cells_ID <- msk_cells_ID[!is.na(raster::getValues(msk))]
     }
     whatList <- list()
     if('class' %in% what){
         Class <- .classValue(statesProb)
         if(spatial == TRUE){
             Class <- match(Class, colnames(statesProb))
-            msk[id] <- Class
-            Class <- msk
+            msk[msk_cells_ID] <- Class
             keyLegend <- data.frame(colnames(statesProb), seq_along(colnames(statesProb)))
-            names(keyLegend) <- c(target, 'ID')
+            names(keyLegend) <- c(target, 'cell_ID')
             if(exportRaster == TRUE){
-                raster::writeRaster(Class, paste(path, '/', target, '_Class', rFormat, sep=''), overwrite=TRUE, datatype='INT2S')
+                .writeOutputMaps(msk, paste(path, '/', target, '_Class', rFormat, sep=''), 'INT2S')
                 utils::write.csv(keyLegend, paste(path, target, '_ClassKey.csv', sep=''), row.names = FALSE)
             } else {
                 writeLines(paste('Lookup table to interpret "', target, '" values:', sep=''))
                 print(keyLegend)
             }
+            Class <- msk
         }
         whatList$Class <- Class
     }
@@ -109,20 +115,22 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
             if('variation' %in% what){
                 Variation <- .variationValue(statesProb, Expected, midvals)
                 if(spatial == TRUE){ 
-                    msk[id] <- Variation
-                    Variation <- msk
+                    msk[msk_cells_ID] <- Variation
                     if(exportRaster == TRUE){
-                        raster::writeRaster(Variation, paste(path, '/', target, '_CoeffVariation', rFormat, sep=''), datatype='FLT4S', overwrite=TRUE)
+                        .writeOutputMaps(msk, paste(path, '/', target, '_CoeffVariation', rFormat, sep=''), 'FLT4S')
+                    } else {
+                        Variation <- msk
                     }
                 }
                 whatList$CoeffVariation <- Variation			
             }
             if('expected' %in% what){
                 if(spatial == TRUE){ 
-                    msk[id] <- Expected
-                    Expected <- msk
+                    msk[msk_cells_ID] <- Expected
                     if(exportRaster == TRUE){
                         raster::writeRaster(Expected, paste(path, '/', target, '_ExpectedValue', rFormat, sep=''), datatype='FLT4S', overwrite=TRUE)
+                    } else{
+                        Expected <- msk
                     }
                 }
                 whatList$ExpectedValue <- Expected
@@ -132,7 +140,7 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
     if('entropy' %in% what){
         Entropy <- .entropyValue(statesProb)
         if(spatial == TRUE){ 
-            msk[id] <- Entropy
+            msk[msk_cells_ID] <- Entropy
             Entropy <- msk
             if(exportRaster == TRUE){
                 raster::writeRaster(Entropy, paste(path, '/', target, '_ShanEntropy', rFormat, sep=''), datatype='FLT4S', overwrite=TRUE)
@@ -143,7 +151,7 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
     if('probability' %in% what){
         Probability <- .probabilityValue(statesProb, targetState)
         if(spatial == TRUE){
-            Probability <- lapply(seq_along(Probability), function(x) {msk[id] <- Probability[[x]]; return(msk)})	
+            Probability <- lapply(seq_along(Probability), function(x) {msk[msk_cells_ID] <- Probability[[x]]; return(msk)})	
         }
         names(Probability) <- targetState
         whatList$Probability <- Probability
@@ -154,8 +162,8 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
         }
     }
     if(spatial == FALSE){
-        xy <- raster::xyFromCell(msk, id)
-        whatList <- cbind(id, xy, as.data.frame(whatList))
+        xy <- raster::xyFromCell(msk, msk_cells_ID)
+        whatList <- cbind(msk_cells_ID, xy, as.data.frame(whatList))
     }
     return(whatList)
 }
@@ -186,3 +194,18 @@ mapTarget <- function(target, statesProb, what=c("class", "entropy"), msk, midva
 .probabilityValue <- function(statesProb, targetState){
     lapply(targetState, function(x) {statesProb[, x]} )
 }
+
+.writeOutputMaps <- function(rst, outFile, datatype){
+    if(raster::canProcessInMemory(rst, 2)){
+        raster::writeRaster(rst, outFile, overwrite=TRUE, datatype=datatype)
+    } else {
+        blocks <- raster::blockSize(rst, minblocks=2)
+        out <- raster::writeStart(rst, outFile, overwrite=TRUE, datatype=datatype) ## open file to write
+        for (i in 1:blocks$n){
+            blockVals <- raster::getValues(rst, row=out$row[i], nrows=out$nrows[i]) ## values from rows to be written
+            out <- raster::writeValues(out, blockVals, out$row[i]) ## populate the raster with values
+        }
+        out <- raster::writeStop(out)
+    }
+}
+
